@@ -52,14 +52,14 @@ get_enum_from_string (EnumStringTable *table,
 	int i;
 
 	/* return the first value if s_value is invalid */
-	
+
 	if (s_value == NULL)
-		return table[0].i_value; 
+		return table[0].i_value;
 
 	for (i = 0; table[i].s_value != NULL; i++)
 		if (strcmp (s_value, table[i].s_value) == 0)
 			return table[i].i_value;
-	
+
 	return table[0].i_value;
 }
 
@@ -73,7 +73,7 @@ get_string_from_enum (EnumStringTable *table,
 	for (i = 0; table[i].s_value != NULL; i++)
 		if (i_value == table[i].i_value)
 			return table[i].s_value;
-	
+
 	/* return the first value if i_value is invalid */
 
 	return table[0].s_value;
@@ -96,6 +96,8 @@ static EnumStringTable arrange_type_table [] = {
         { GTH_SORT_METHOD_BY_PATH, "path" },
         { GTH_SORT_METHOD_BY_SIZE, "size" },
         { GTH_SORT_METHOD_BY_TIME, "time" },
+        { GTH_SORT_METHOD_BY_COMMENT, "comment" },
+	{ GTH_SORT_METHOD_BY_EXIF_DATE, "exifdate" },
         { GTH_SORT_METHOD_MANUAL,  "manual" },
 	{ 0, NULL }
 };
@@ -121,10 +123,11 @@ static EnumStringTable zoom_quality_table [] = {
 };
 
 static EnumStringTable zoom_change_table [] = {
-	{ GTH_ZOOM_CHANGE_FIT_IF_LARGER, "fit_if_larger" },
-	{ GTH_ZOOM_CHANGE_ACTUAL_SIZE,   "actual_size" },
-	{ GTH_ZOOM_CHANGE_FIT,           "fit" },
-	{ GTH_ZOOM_CHANGE_KEEP_PREV,     "keep_prev" },
+	{ GTH_ZOOM_CHANGE_ACTUAL_SIZE,         "actual_size" },
+	{ GTH_ZOOM_CHANGE_KEEP_PREV,           "keep_prev" },
+	{ GTH_ZOOM_CHANGE_FIT_SIZE,            "fit" },
+	{ GTH_ZOOM_CHANGE_FIT_SIZE_IF_LARGER,  "fit_if_larger" },
+	{ GTH_ZOOM_CHANGE_FIT_WIDTH_IF_LARGER, "fit_width_if_larger" },
 	{ 0, NULL }
 };
 
@@ -204,6 +207,27 @@ static EnumStringTable print_unit_table [] = {
 	{ 0, NULL }
 };
 
+static EnumStringTable image_unit_table [] = {
+	{ GTH_PRINT_UNIT_MM,     "mm" },
+	{ GTH_PRINT_UNIT_IN,     "in" },
+	{ 0, NULL }
+};
+
+static EnumStringTable image_resolution_table [] = {
+	{ GTH_IMAGE_RESOLUTION_72,      "72" },
+	{ GTH_IMAGE_RESOLUTION_150,     "150" },
+	{ GTH_IMAGE_RESOLUTION_300,     "300" },
+	{ GTH_IMAGE_RESOLUTION_600,     "600" },
+	{ 0, NULL }
+};
+
+
+static EnumStringTable image_sizing_table [] = {
+	{ GTH_IMAGE_SIZING_AUTO,    "auto" },
+	{ GTH_IMAGE_SIZING_MANUAL,  "manual" },
+	{ 0, NULL }
+};
+
 static EnumStringTable crop_ratio_table [] = {
 	{ GTH_CROP_RATIO_NONE,     "none" },
 	{ GTH_CROP_RATIO_SQUARE,   "square" },
@@ -220,7 +244,7 @@ static EnumStringTable crop_ratio_table [] = {
 /* --------------- */
 
 
-void 
+void
 preferences_init (void)
 {
 	GConfClient *client;
@@ -292,86 +316,6 @@ preferences_get_startup_location (void)
 
 
 
-const char * 
-pref_util_get_file_location (const char *location)
-{
-	if (g_utf8_strlen (location, -1) <= FILE_PREFIX_L)
-		return NULL;
-	return location + FILE_PREFIX_L;
-}
-
-
-const char * 
-pref_util_get_catalog_location (const char *location)
-{
-	if (g_utf8_strlen (location, -1) <= CATALOG_PREFIX_L)
-		return NULL;
-	return location + CATALOG_PREFIX_L;
-}
-
-
-const char * 
-pref_util_get_search_location (const char *location)
-{
-	if (g_utf8_strlen (location, -1) <= SEARCH_PREFIX_L)
-		return NULL;
-	return location + SEARCH_PREFIX_L;
-}
-
-
-gboolean
-pref_util_location_is_file (const char *location)
-{
-	if (location == NULL)
-		return FALSE;
-
-	if (g_utf8_strlen (location, -1) <= FILE_PREFIX_L)
-		return FALSE;
-
-	return strncmp (location, FILE_PREFIX, FILE_PREFIX_L) == 0;
-}
-
-
-gboolean
-pref_util_location_is_catalog (const char *location)
-{
-	if (location == NULL)
-		return FALSE;
-
-	if (g_utf8_strlen (location, -1) <= CATALOG_PREFIX_L)
-		return FALSE;
-
-	return strncmp (location, CATALOG_PREFIX, CATALOG_PREFIX_L) == 0;
-}
-
-
-gboolean
-pref_util_location_is_search (const char *location)
-{
-	if (location == NULL)
-		return FALSE;
-
-	if (g_utf8_strlen (location, -1) <= SEARCH_PREFIX_L)
-		return FALSE;
-
-	return strncmp (location, SEARCH_PREFIX, SEARCH_PREFIX_L) == 0;
-}
-
-
-const char *
-pref_util_remove_prefix (const char *location)
-{
-	if (pref_util_location_is_catalog (location))
-		return pref_util_get_catalog_location (location);
-	else if (pref_util_location_is_search (location))
-		return pref_util_get_search_location (location);
-	else if (pref_util_location_is_file (location))
-		return pref_util_get_file_location (location);
-	else
-		return location;
-}
-
-
 GthClickPolicy
 pref_get_real_click_policy (void)
 {
@@ -426,7 +370,7 @@ pref_util_get_rgb_values (const char *hex,
 		*r = dec (hex[1]) * 16 + dec (hex[2]);
 		*g = dec (hex[3]) * 16 + dec (hex[4]);
 		*b = dec (hex[5]) * 16 + dec (hex[6]);
-		
+
 		*r = UNSCALE (*r / 255.);
 		*g = UNSCALE (*g / 255.);
 		*b = UNSCALE (*b / 255.);
@@ -535,26 +479,29 @@ pref_set_##func_name (type i_value)					\
 }
 
 
-GET_SET_FUNC(click_policy,           PREF_CLICK_POLICY,        GthClickPolicy)
-GET_SET_FUNC(arrange_type,           PREF_ARRANGE_IMAGES,      GthSortMethod)
-GET_SET_FUNC(sort_order,             PREF_SORT_IMAGES,         GtkSortType)
-GET_SET_FUNC(zoom_quality,           PREF_ZOOM_QUALITY,        GthZoomQuality)
-GET_SET_FUNC(zoom_change,            PREF_ZOOM_CHANGE,         GthZoomChange)
-GET_SET_FUNC(transp_type,            PREF_TRANSP_TYPE,         GthTranspType)
-GET_SET_FUNC(check_type,             PREF_CHECK_TYPE,          GthCheckType)
-GET_SET_FUNC(check_size,             PREF_CHECK_SIZE,          GthCheckSize)
-GET_SET_FUNC(slideshow_direction,    PREF_SLIDESHOW_DIR,       GthDirectionType)
-GET_SET_FUNC(toolbar_style,          PREF_UI_TOOLBAR_STYLE,    GthToolbarStyle)
-GET_SET_FUNC(exp_arrange_type,       PREF_EXP_ARRANGE_IMAGES,  GthSortMethod)
-GET_SET_FUNC(exp_sort_order,         PREF_EXP_SORT_IMAGES,     GtkSortType)
-GET_SET_FUNC(exporter_frame_style,   PREF_EXP_FRAME_STYLE,     GthFrameStyle)
-GET_SET_FUNC(convert_overwrite_mode, PREF_CONVERT_OVERWRITE,   GthOverwriteMode)
-GET_SET_FUNC(rename_sort_order,      PREF_RENAME_SERIES_SORT,  GthSortMethod)
-GET_SET_FUNC(web_album_sort_order,   PREF_WEB_ALBUM_SORT,      GthSortMethod)
-GET_SET_FUNC(view_as,                PREF_VIEW_AS,             GthViewAs)
-GET_SET_FUNC(preview_content,        PREF_PREVIEW_CONTENT,     GthPreviewContent)
-GET_SET_FUNC(print_unit,             PREF_PRINT_PAPER_UNIT,    GthPrintUnit)
-GET_SET_FUNC(crop_ratio,             PREF_CROP_ASPECT_RATIO,   GthCropRatio)
+GET_SET_FUNC(click_policy,           PREF_CLICK_POLICY,            GthClickPolicy)
+GET_SET_FUNC(arrange_type,           PREF_ARRANGE_IMAGES,          GthSortMethod)
+GET_SET_FUNC(sort_order,             PREF_SORT_IMAGES,             GtkSortType)
+GET_SET_FUNC(zoom_quality,           PREF_ZOOM_QUALITY,            GthZoomQuality)
+GET_SET_FUNC(zoom_change,            PREF_ZOOM_CHANGE,             GthZoomChange)
+GET_SET_FUNC(transp_type,            PREF_TRANSP_TYPE,             GthTranspType)
+GET_SET_FUNC(check_type,             PREF_CHECK_TYPE,              GthCheckType)
+GET_SET_FUNC(check_size,             PREF_CHECK_SIZE,              GthCheckSize)
+GET_SET_FUNC(slideshow_direction,    PREF_SLIDESHOW_DIR,           GthDirectionType)
+GET_SET_FUNC(toolbar_style,          PREF_UI_TOOLBAR_STYLE,        GthToolbarStyle)
+GET_SET_FUNC(exp_arrange_type,       PREF_EXP_ARRANGE_IMAGES,      GthSortMethod)
+GET_SET_FUNC(exp_sort_order,         PREF_EXP_SORT_IMAGES,         GtkSortType)
+GET_SET_FUNC(exporter_frame_style,   PREF_EXP_FRAME_STYLE,         GthFrameStyle)
+GET_SET_FUNC(convert_overwrite_mode, PREF_CONVERT_OVERWRITE,       GthOverwriteMode)
+GET_SET_FUNC(rename_sort_order,      PREF_RENAME_SERIES_SORT,      GthSortMethod)
+GET_SET_FUNC(web_album_sort_order,   PREF_WEB_ALBUM_SORT,          GthSortMethod)
+GET_SET_FUNC(view_as,                PREF_VIEW_AS,                 GthViewAs)
+GET_SET_FUNC(preview_content,        PREF_PREVIEW_CONTENT,         GthPreviewContent)
+GET_SET_FUNC(print_unit,             PREF_PRINT_PAPER_UNIT,        GthPrintUnit)
+GET_SET_FUNC(image_unit,             PREF_PRINT_IMAGE_UNIT,        GthPrintUnit)
+GET_SET_FUNC(image_sizing,           PREF_PRINT_IMAGE_SIZING,      GthImageSizing)
+GET_SET_FUNC(image_resolution,       PREF_PRINT_IMAGE_RESOLUTION,  GthImageResolution)
+GET_SET_FUNC(crop_ratio,             PREF_CROP_ASPECT_RATIO,       GthCropRatio)
 
 
 GthViewMode
@@ -612,8 +559,8 @@ pref_get_real_toolbar_style (void)
 
 
 static void
-set_dialog_property_int (const char *dialog, 
-			 const char *property, 
+set_dialog_property_int (const char *dialog,
+			 const char *property,
 			 int         value)
 {
 	char *key;
@@ -631,17 +578,17 @@ pref_util_save_window_geometry (GtkWindow  *window,
 	int x, y, width, height;
 
 	gtk_window_get_position (window, &x, &y);
-	set_dialog_property_int (dialog, "x", x); 
-	set_dialog_property_int (dialog, "y", y); 
+	set_dialog_property_int (dialog, "x", x);
+	set_dialog_property_int (dialog, "y", y);
 
 	gtk_window_get_size (window, &width, &height);
-	set_dialog_property_int (dialog, "width", width); 
-	set_dialog_property_int (dialog, "height", height); 
+	set_dialog_property_int (dialog, "width", width);
+	set_dialog_property_int (dialog, "height", height);
 }
 
 
 static int
-get_dialog_property_int (const char *dialog, 
+get_dialog_property_int (const char *dialog,
 			 const char *property)
 {
 	char *key;
@@ -666,7 +613,7 @@ pref_util_restore_window_geometry (GtkWindow  *window,
 	width = get_dialog_property_int (dialog, "width");
 	height = get_dialog_property_int (dialog, "height");
 
-	if (width != -1 && height != 1) 
+	if (width != -1 && height != 1)
 		gtk_window_set_default_size (window, width, height);
 
 	gtk_window_present (window);
